@@ -61,7 +61,7 @@ namespace xsimd
 
             static_assert(A::supported(),
                           "usage of batch type with unsupported architecture");
-            static_assert(!A::supported() || has_simd_register<T, A>::value,
+            static_assert(!A::supported() || xsimd::has_simd_register<T, A>::value,
                           "usage of batch type with unsupported type");
         };
 
@@ -86,20 +86,20 @@ namespace xsimd
     }
 
     template <class T>
-    struct simd_traits : detail::simd_traits_impl<T, has_simd_register<T>::value>
+    struct simd_traits : detail::simd_traits_impl<T, xsimd::has_simd_register<T>::value>
     {
     };
 
     template <class T>
     struct simd_traits<std::complex<T>>
-        : detail::simd_traits_impl<std::complex<T>, has_simd_register<T>::value>
+        : detail::simd_traits_impl<std::complex<T>, xsimd::has_simd_register<T>::value>
     {
     };
 
 #ifdef XSIMD_ENABLE_XTL_COMPLEX
     template <class T, bool i3ec>
     struct simd_traits<xtl::xcomplex<T, T, i3ec>>
-        : detail::simd_traits_impl<std::complex<T>, has_simd_register<T>::value>
+        : detail::simd_traits_impl<std::complex<T>, xsimd::has_simd_register<T>::value>
     {
     };
 #endif
@@ -150,13 +150,6 @@ namespace xsimd
             : std::enable_if<simd_condition<T1, T2>::value, batch<T2, A>>
         {
         };
-        template <class A>
-        struct simd_return_type_impl<char, char, A>
-            : std::conditional<std::is_signed<char>::value,
-                               simd_return_type_impl<int8_t, int8_t, A>,
-                               simd_return_type_impl<uint8_t, uint8_t, A>>::type
-        {
-        };
 
         template <class T2, class A>
         struct simd_return_type_impl<bool, T2, A>
